---
name: v.in.mapgen.py
description: Imports Mapgen or Matlab-ASCII vector maps into GRASS.
keywords: [ vector, import ]
---

# v.in.mapgen.py

Imports Mapgen or Matlab-ASCII vector maps into GRASS.

=== "Command line"

    **v.in.mapgen.py**
    [**-fz**]
    **input**=*name*
    [**output**=*name*]
    [**--overwrite**]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    v.in.mapgen.py input=name
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***v.in.mapgen.py***",
        **input**,
        **output**=*None*,
        **flags**=*None*,
        **overwrite**=*False*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("v.in.mapgen.py", input="name")
    ```

## Parameters

=== "Command line"

    **input**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input file in Mapgen/Matlab format  
    **output**=*name*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map (omit for display to stdout)  
    **-f**  
    &nbsp;&nbsp;&nbsp;&nbsp;Input map is in Matlab format  
    **-z**  
    &nbsp;&nbsp;&nbsp;&nbsp;Create a 3D vector points map from 3 column Matlab data  
    **--overwrite**  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **input** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input file in Mapgen/Matlab format  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, file, *name*  
    **output** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map (omit for display to stdout)  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: output, vector, *name*  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *f*, *z*  
    &nbsp;&nbsp;&nbsp;&nbsp;**f**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Input map is in Matlab format  
    &nbsp;&nbsp;&nbsp;&nbsp;**z**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Create a 3D vector points map from 3 column Matlab data  
    **overwrite**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*v.in.mapgen* allows the user to import Mapgen or Matlab vector maps
into GRASS.

## NOTES

This module only imports data into vector lines.

The user can get coastline data in Mapgen or Matlab format from NOAA's
Coastline Extractor at
<https://www.ngdc.noaa.gov/mgg/shorelines/shorelines.html>.

Matlab vector line maps are simply a series of "x y" data points. Lines
are separated by a row containing `NaN NaN`. Output from Matlab with
this command:  

```sh
    save filename.txt arrayname -ASCII
```

The user can import 3D lines from Matlab by exporting a 3 column array
and using the **-z** flag.

## SEE ALSO

*[v.in.ascii](v.in.ascii.md)*

## AUTHORS

Based on *v.in.mapgen.sh* for GRASS 5.0 by Andreas Lange  
Rewritten for GRASS 6 by Hamish Bowman

## SOURCE CODE

Available at: [v.in.mapgen source code](https://github.com/OSGeo/grass/tree/main/scripts/v.in.mapgen)
([history](https://github.com/OSGeo/grass/commits/main/scripts/v.in.mapgen))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
